@@ -1,4 +1,6 @@
 from .code_tokenizer import PyTokenizer, Tokenizer
+from .common import stack_mappings
 from .distributed import rank_zero_only
 from .html_stripper import HTMLStripper
+from .resolvers import resolve_object
 from .unidiff_builder import UnidiffBuilder
